@@ -604,7 +604,6 @@ class Session(BaseModel):
     """Dataclass for transaction session."""
 
     status: str
-    sessionkey: str
     tran_date: datetime
     tran_id: str
     val_id: str
@@ -622,18 +621,18 @@ class Session(BaseModel):
     risk_level: RiskLevelEnum
     risk_title: str
 
+    sessionkey: Optional[str]
     error: Optional[str]
     currency: Optional[str]
-    emi_instalment: Optional[int]
-    emi_amount: Optional[int]
-    discount_percentage: Optional[Decimal]
+    emi_instalment: Optional[Union[Decimal, str]]
+    emi_amount: Optional[Union[Decimal, str]]
+    discount_percentage: Optional[Union[Decimal, str]]
     discount_remarks: Optional[str]
     value_a: Optional[str]
     value_b: Optional[str]
     value_c: Optional[str]
     value_d: Optional[str]
 
-
 class TransactionBySessionResponse(Session):
     """Dataclass for transaction by session query."""
 
